//Maya ASCII 1.0 scene
//Name: the_shaker.ma
//Last modified: Wed, Dec  2, 98 05:16:43 PM
requires maya "1.0";




/*

the shaker By Richard C Morris
Mail: jackal@jackals-forge.com
Last modified: Wed, Dec 2, 98 04:13:05 PM



******************************   DESCRIPTION
********************************

the shaker is a single node which was written primarily to create the
effect of camera
shake. However, it may be used in various other ways, shaking objects,
swaying objects
(e.g. in the wind) or driving other animation (e.g. wavering colour of a
shader)

******************************   INSTRUCTIONS
********************************




The principal controls:

make the shaker node the parent of your camera (or object etc..). This
scene file
should create the shaker control window for easy adjustmnent and
animation (all
attributes are in the attribute editor as well, under 'extra'). If you
lose the control
window, call the procedure by typing shakecontrol in the maya command
line.

1. The principal control Shake_intensity simulates random translation
and rotation by
generating a gaussian random number of a second normal random number. In
this way,
the object's shake will follow a gaussian, bell shaped distribution
giving most movement
within a certain range and only few occurences of large deviation.

2. Jitter_intensity creates a more standard random movement using the
rand (x,y) function

3. Wander_intensity will generate cumulative translation so that your
grouped
geometry will not come back to the same resting place (e.g. camera not
firmly attached)
and will actually wander

4. Destabilise_intensity will simulate a slower, gradual random movement
and rotation by
using the noise (time) function. This was primarily created to introduce
more offset
for the overall camera shake as if the camera holder was actually
shifting position
globally over time as a result of the main shake. On its own it creates
a very nice effect
and could find many more uses (e.g. swaying objects in the wind, max
headroom ??)




The fine controls:

the above 4 primary controls can be intensity adjusted at the channel
level
(wander produces no rotation). shake in the z axis may for example, not
be
required etc...

the destabilise fine controls multiply the 'time' i.e. noise (time * x)
so
time is effectively compressed, giving a higher rate of change of
movement.
The principal intensity controls the magnitude of movement.





NB:

Particular attention should obviously be paid to the pivot point of the
shaker node.
Whilst it wil be often favourable to match  this to your camera or
object's pivot
point, offsetting can produce interesting results.

Once the shaker has been configured, it is best to bake simulation on
the xyz trans and
rotation channels then delete all expressions.

With destabilistaion on, wander intensity will produce very large
wanders !! They do not really
work together.


*/









currentUnit -l centimeter -a degree -t film;
createNode transform -n "the_shaker";
 addAttr -ci true -sn "shake_intensity" -ln "shake_intensity" -min 0
-max
  10 -at "double";
 addAttr -ci true -sn "destabilise_intensity" -ln
"destabilise_intensity"
  -min 0 -max 10 -at "double";
 addAttr -ci true -sn "wander_intensity" -ln "wander_intensity" -min 0
-max
  10 -at "double";
 addAttr -ci true -sn "jitter_intensity" -ln "jitter_intensity" -min 0
-max
  10 -at "double";
 addAttr -ci true -sn "shake_xtrans_master" -ln "shake_xtrans_master"
-min
  0 -max 10 -at "double";
 addAttr -ci true -sn "shake_ytrans_master" -ln "shake_ytrans_master"
-min
  0 -max 10 -at "double";
 addAttr -ci true -sn "shake_ztrans_master" -ln "shake_ztrans_master"
-min
  0 -max 10 -at "double";
 addAttr -ci true -sn "shake_xrot_master" -ln "shake_xrot_master" -min 0

  -max 10 -at "double";
 addAttr -ci true -sn "shake_yrot_master" -ln "shake_yrot_master" -min 0

  -max 10 -at "double";
 addAttr -ci true -sn "shake_zrot_master" -ln "shake_zrot_master" -min 0

  -max 10 -at "double";
 addAttr -ci true -sn "destabilise_xtrans_scale" -ln
"destabilise_xtrans_scale"
  -min 0 -max 10 -at "double";
 addAttr -ci true -sn "destabilise_ytrans_scale" -ln
"destabilise_ytrans_scale"
  -min 0 -max 10 -at "double";
 addAttr -ci true -sn "destabilise_ztrans_scale" -ln
"destabilise_ztrans_scale"
  -min 0 -max 10 -at "double";
 addAttr -ci true -sn "destabilise_xrot_scale" -ln
"destabilise_xrot_scale"
  -min 0 -max 10 -at "double";
 addAttr -ci true -sn "destabilise_yrot_scale" -ln
"destabilise_yrot_scale"
  -min 0 -max 10 -at "double";
 addAttr -ci true -sn "destabilise_zrot_scale" -ln
"destabilise_zrot_scale"
  -min 0 -max 10 -at "double";
 addAttr -ci true -sn "wander_xtrans_master" -ln "wander_xtrans_master"
-min
  0 -max 10 -at "double";
 addAttr -ci true -sn "wander_ytrans_master" -ln "wander_ytrans_master"
-min
  0 -max 10 -at "double";
 addAttr -ci true -sn "wander_ztrans_master" -ln "wander_ztrans_master"
-min
  0 -max 10 -at "double";
 addAttr -ci true -sn "jitter_xtrans_master" -ln "jitter_xtrans_master"
-min
  0 -max 10 -at "double";
 addAttr -ci true -sn "jitter_ytrans_master" -ln "jitter_ytrans_master"
-min
  0 -max 10 -at "double";
 addAttr -ci true -sn "jitter_ztrans_master" -ln "jitter_ztrans_master"
-min
  0 -max 10 -at "double";
 addAttr -ci true -sn "jitter_xrot_master" -ln "jitter_xrot_master" -min

  0 -max 10 -at "double";
 addAttr -ci true -sn "jitter_yrot_master" -ln "jitter_yrot_master" -min

  0 -max 10 -at "double";
 addAttr -ci true -sn "jitter_zrot_master" -ln "jitter_zrot_master" -min

  0 -max 10 -at "double";
 setAttr -k on ".shake_intensity";
 setAttr -k on ".destabilise_intensity";
 setAttr -k on ".wander_intensity";
 setAttr -k on ".jitter_intensity";
 setAttr -k on ".shake_xtrans_master";
 setAttr -k on ".shake_ytrans_master";
 setAttr -k on ".shake_ztrans_master";
 setAttr -k on ".shake_xrot_master";
 setAttr -k on ".shake_yrot_master";
 setAttr -k on ".shake_zrot_master";
 setAttr -k on ".destabilise_xtrans_scale";
 setAttr -k on ".destabilise_ytrans_scale";
 setAttr -k on ".destabilise_ztrans_scale";
 setAttr -k on ".destabilise_xrot_scale";
 setAttr -k on ".destabilise_yrot_scale";
 setAttr -k on ".destabilise_zrot_scale";
 setAttr -k on ".wander_xtrans_master";
 setAttr -k on ".wander_ytrans_master";
 setAttr -k on ".wander_ztrans_master";
 setAttr -k on ".jitter_xtrans_master";
 setAttr -k on ".jitter_ytrans_master";
 setAttr -k on ".jitter_ztrans_master";
 setAttr -k on ".jitter_xrot_master";
 setAttr -k on ".jitter_yrot_master";
 setAttr -k on ".jitter_zrot_master";
createNode expression -n "expression_shaker_xtrans";
 setAttr -s 8 ".in";
 setAttr ".ixp" -type "string" "if (.I[0] == 0 )\n\n.O[0] = (   gauss (
( rand ( 0 , ( .I[1] * (.I[2] * 0.1 ) ))))   )   +\n(   ( (noise
((time-50) * .I[3])) * (.I[4]/2) )   )   +\n( rand (.I[5] * (.I[6]/10),
(.I[5] * -1 * (.I[6]/10)) ) );\n\nelse\n\n.O[0] = (   gauss ( ( rand ( 0
, ( .I[1] * (.I[2] * 0.1 ) ))))   )   +\n(   ( (noise ((time-50) *
.I[3])) * (.I[4]/2) )   )   +\n( rand (.I[5] * (.I[6]/10), (.I[5] * -1 *
(.I[6]/10)) ) )\n+ .O[0]\n+ (( rand  ( - (.I[0] * (.I[7]/5)) , (.I[0]
*(.I[7]/5) )  )    ))" ;
createNode expression -n "expression_shaker_ytans";
 setAttr -s 8 ".in";
 setAttr ".ixp" -type "string" "if (.I[0] == 0 )\n\n\n.O[0] = (   gauss
( ( rand ( 0 , ( .I[1] * (.I[2] * 0.1 ) ))))   )   +\n(   ( (noise
((time) * .I[3])) * (.I[4]/2) )   )   +\n( rand (.I[5] * (.I[6]/10),
(.I[5] * -1 * (.I[6]/10)) ) );\n\nelse\n\n.O[0] = (   gauss ( ( rand ( 0
, ( .I[1] * (.I[2] * 0.1 ) ))))   )   +\n(   ( (noise ((time) * .I[3]))
* (.I[4]/2) )   )   +\n( rand (.I[5] * (.I[6]/10), (.I[5] * -1 *
(.I[6]/10)) ) )\n+ .O[0]\n+ (( rand  ( - (.I[0] * (.I[7]/5)) , (.I[0]
*(.I[7]/5) )  )    ))" ;
createNode expression -n "expression_shaker_ztrans";
 setAttr -s 8 ".in";
 setAttr ".ixp" -type "string" "if (.I[0] == 0 )\n\n.O[0] = (    gauss (
( rand ( 0 , ( .I[1] * (.I[2] * 0.1 ) ))))   )    +\n(   ( (noise
((time-90) * .I[3])) * (.I[4]/2) )   )   +\n( rand (.I[5] * (.I[6]/10),
(.I[5] * -1 * (.I[6]/10)) ) );\n\nelse\n\n.O[0] = (    gauss ( ( rand (
0 , ( .I[1] * (.I[2] * 0.1 ) ))))   )    +\n(   ( (noise ((time-90) *
.I[3])) * (.I[4]/2) )   )   +\n( rand (.I[5] * (.I[6]/10), (.I[5] * -1 *
(.I[6]/10)) ) )\n+  .O[0]\n+ (( rand  ( - (.I[0] * (.I[7]/5)) , (.I[0]
*(.I[7]/5) )  )    ))" ;
createNode unitConversion -n "unitConversion39";
 setAttr ".cf" 0.017453292519943295;
createNode expression -n "expression_shaker_xrot";
 setAttr -s 6 ".in";
 setAttr ".ixp" -type "string" ".O[0] =  (    gauss ( ( rand ( 0 , (
.I[0] * (.I[1] * 0.1 ) ))))   )    +\n(   ( (noise ((time-50) * .I[2]))
* (.I[3] * 2) )   )   +\n( rand (.I[4] * (.I[5]/10), (.I[4] * -1 *
(.I[5]/10)) ) )" ;
createNode unitConversion -n "unitConversion38";
 setAttr ".cf" 0.017453292519943295;
createNode expression -n "expression_shaker_yrot";
 setAttr -s 6 ".in";
 setAttr ".ixp" -type "string" ".O[0] = (   gauss ( ( rand ( 0 , ( .I[0]
* (.I[1] * 0.1 ) ))))   )   +\n(   ( (noise ((time) * .I[2])) * (.I[3] *
2) )   )  +\n( rand (.I[4] * (.I[5]/10), (.I[4] * -1 * (.I[5]/10)) ) )"
;
createNode unitConversion -n "unitConversion40";
 setAttr ".cf" 0.017453292519943295;
createNode expression -n "expression_shaker_zrot";
 setAttr -s 6 ".in";
 setAttr ".ixp" -type "string" ".O[0] = (   gauss ( ( rand ( 0 , ( .I[0]
* (.I[1] * 0.1 ) ))))    )    +\n(   ( (noise ((time-90) * .I[2])) *
(.I[3] * 2) )   )  +\n ( rand (.I[4] * (.I[5]/10), (.I[4] * -1 *
(.I[5]/10)) ) )" ;
connectAttr "expression_shaker_xtrans.out[0]" "the_shaker.tx";
connectAttr "expression_shaker_ytans.out[0]" "the_shaker.ty";
connectAttr "expression_shaker_ztrans.out[0]" "the_shaker.tz";
connectAttr "unitConversion39.o" "the_shaker.rx";
connectAttr "unitConversion38.o" "the_shaker.ry";
connectAttr "unitConversion40.o" "the_shaker.rz";
connectAttr "the_shaker.wander_intensity"
"expression_shaker_xtrans.in[0]"
  ;
connectAttr "the_shaker.shake_intensity"
"expression_shaker_xtrans.in[1]"
  ;
connectAttr "the_shaker.shake_xtrans_master"
"expression_shaker_xtrans.in[2]"
  ;
connectAttr "the_shaker.destabilise_xtrans_scale"
"expression_shaker_xtrans.in[3]"
  ;
connectAttr "the_shaker.destabilise_intensity"
"expression_shaker_xtrans.in[4]"
  ;
connectAttr "the_shaker.jitter_intensity"
"expression_shaker_xtrans.in[5]"
  ;
connectAttr "the_shaker.jitter_xtrans_master"
"expression_shaker_xtrans.in[6]"
  ;
connectAttr "the_shaker.wander_xtrans_master"
"expression_shaker_xtrans.in[7]"
  ;
connectAttr "time1.o" "expression_shaker_xtrans.tim";
connectAttr "the_shaker.msg" "expression_shaker_xtrans.obm";
connectAttr "the_shaker.wander_intensity"
"expression_shaker_ytans.in[0]"
  ;
connectAttr "the_shaker.shake_intensity" "expression_shaker_ytans.in[1]"

  ;
connectAttr "the_shaker.shake_ytrans_master"
"expression_shaker_ytans.in[2]"
  ;
connectAttr "the_shaker.destabilise_ytrans_scale"
"expression_shaker_ytans.in[3]"
  ;
connectAttr "the_shaker.destabilise_intensity"
"expression_shaker_ytans.in[4]"
  ;
connectAttr "the_shaker.jitter_intensity"
"expression_shaker_ytans.in[5]"
  ;
connectAttr "the_shaker.jitter_ytrans_master"
"expression_shaker_ytans.in[6]"
  ;
connectAttr "the_shaker.wander_ytrans_master"
"expression_shaker_ytans.in[7]"
  ;
connectAttr "time1.o" "expression_shaker_ytans.tim";
connectAttr "the_shaker.msg" "expression_shaker_ytans.obm";
connectAttr "the_shaker.wander_intensity"
"expression_shaker_ztrans.in[0]"
  ;
connectAttr "the_shaker.shake_intensity"
"expression_shaker_ztrans.in[1]"
  ;
connectAttr "the_shaker.shake_ztrans_master"
"expression_shaker_ztrans.in[2]"
  ;
connectAttr "the_shaker.destabilise_ztrans_scale"
"expression_shaker_ztrans.in[3]"
  ;
connectAttr "the_shaker.destabilise_intensity"
"expression_shaker_ztrans.in[4]"
  ;
connectAttr "the_shaker.jitter_intensity"
"expression_shaker_ztrans.in[5]"
  ;
connectAttr "the_shaker.jitter_ztrans_master"
"expression_shaker_ztrans.in[6]"
  ;
connectAttr "the_shaker.wander_ztrans_master"
"expression_shaker_ztrans.in[7]"
  ;
connectAttr "time1.o" "expression_shaker_ztrans.tim";
connectAttr "the_shaker.msg" "expression_shaker_ztrans.obm";
connectAttr "expression_shaker_xrot.out[0]" "unitConversion39.i";
connectAttr "the_shaker.shake_intensity" "expression_shaker_xrot.in[0]";

connectAttr "the_shaker.shake_xrot_master"
"expression_shaker_xrot.in[1]"
  ;
connectAttr "the_shaker.destabilise_xrot_scale"
"expression_shaker_xrot.in[2]"
  ;
connectAttr "the_shaker.destabilise_intensity"
"expression_shaker_xrot.in[3]"
  ;
connectAttr "the_shaker.jitter_intensity" "expression_shaker_xrot.in[4]"

  ;
connectAttr "the_shaker.jitter_xrot_master"
"expression_shaker_xrot.in[5]"
  ;
connectAttr "time1.o" "expression_shaker_xrot.tim";
connectAttr "the_shaker.msg" "expression_shaker_xrot.obm";
connectAttr "expression_shaker_yrot.out[0]" "unitConversion38.i";
connectAttr "the_shaker.shake_intensity" "expression_shaker_yrot.in[0]";

connectAttr "the_shaker.shake_yrot_master"
"expression_shaker_yrot.in[1]"
  ;
connectAttr "the_shaker.destabilise_yrot_scale"
"expression_shaker_yrot.in[2]"
  ;
connectAttr "the_shaker.destabilise_intensity"
"expression_shaker_yrot.in[3]"
  ;
connectAttr "the_shaker.jitter_intensity" "expression_shaker_yrot.in[4]"

  ;
connectAttr "the_shaker.jitter_yrot_master"
"expression_shaker_yrot.in[5]"
  ;
connectAttr "time1.o" "expression_shaker_yrot.tim";
connectAttr "the_shaker.msg" "expression_shaker_yrot.obm";
connectAttr "expression_shaker_zrot.out[0]" "unitConversion40.i";
connectAttr "the_shaker.shake_intensity" "expression_shaker_zrot.in[0]";

connectAttr "the_shaker.shake_zrot_master"
"expression_shaker_zrot.in[1]"
  ;
connectAttr "the_shaker.destabilise_zrot_scale"
"expression_shaker_zrot.in[2]"
  ;
connectAttr "the_shaker.destabilise_intensity"
"expression_shaker_zrot.in[3]"
  ;
connectAttr "the_shaker.jitter_intensity" "expression_shaker_zrot.in[4]"

  ;
connectAttr "the_shaker.jitter_zrot_master"
"expression_shaker_zrot.in[5]"
  ;
connectAttr "time1.o" "expression_shaker_zrot.tim";
connectAttr "the_shaker.msg" "expression_shaker_zrot.obm";


window -title "The Shaker - R.C.Morris 1998" shakecontrol;

 scrollLayout scrollLayout;
  columnLayout -adjustableColumn true col1;
   frameLayout -label "PRINCIPAL CONTROL" -labelAlign "top"
    -borderStyle "in";
     columnLayout;



   attrFieldSliderGrp -min 0 -max 10.0 -at the_shaker.shake_intensity;
   attrFieldSliderGrp -min 0 -max 10.0 -at the_shaker.jitter_intensity;
   attrFieldSliderGrp -min 0 -max 10.0 -at the_shaker.wander_intensity;
   attrFieldSliderGrp -min 0 -max 10.0 -at
the_shaker.destabilise_intensity;

     setParent ..;
    setParent ..;

   frameLayout -label "FINE CONTROL" -labelAlign "center" -collapsable
true -collapse false
     -borderStyle "etchedOut";
     columnLayout;


   attrFieldSliderGrp -label Shake_tx -min 0 -max 10.0 -at
the_shaker.shake_xtrans_master;
   attrFieldSliderGrp -label Shake_ty -min 0 -max 10.0 -at
the_shaker.shake_ytrans_master;
   attrFieldSliderGrp -label Shake_tz -min 0 -max 10.0 -at
the_shaker.shake_ztrans_master;
   attrFieldSliderGrp -label Shake_rx -min 0 -max 10.0 -at
the_shaker.shake_xrot_master;
   attrFieldSliderGrp -label Shake_ry -min 0 -max 10.0 -at
the_shaker.shake_yrot_master;
   attrFieldSliderGrp -label Shake_rz -min 0 -max 10.0 -at
the_shaker.shake_zrot_master;
   attrFieldSliderGrp -label Jitter_tx -min 0 -max 10.0 -at
the_shaker.jitter_xtrans_master;
   attrFieldSliderGrp -label Jitter_ty -min 0 -max 10.0 -at
the_shaker.jitter_ytrans_master;
   attrFieldSliderGrp -label Jitter_tz -min 0 -max 10.0 -at
the_shaker.jitter_ztrans_master;
   attrFieldSliderGrp -label Jitter_rx -min 0 -max 10.0 -at
the_shaker.jitter_xrot_master;
   attrFieldSliderGrp -label Jitter_ry -min 0 -max 10.0 -at
the_shaker.jitter_yrot_master;
   attrFieldSliderGrp -label Jitter_rz -min 0 -max 10.0 -at
the_shaker.jitter_zrot_master;
   attrFieldSliderGrp -label Destabilise_tx -min 0 -max 10.0 -at
the_shaker.destabilise_xtrans_scale;
   attrFieldSliderGrp -label Destabilise_ty -min 0 -max 10.0 -at
the_shaker.destabilise_ytrans_scale;
   attrFieldSliderGrp -label Destabilise_tz -min 0 -max 10.0 -at
the_shaker.destabilise_ztrans_scale;
   attrFieldSliderGrp -label Destabilise_rx -min 0 -max 10.0 -at
the_shaker.destabilise_xrot_scale;
   attrFieldSliderGrp -label Destabilise_ry -min 0 -max 10.0 -at
the_shaker.destabilise_yrot_scale;
   attrFieldSliderGrp -label Destabilise_rz -min 0 -max 10.0 -at
the_shaker.destabilise_zrot_scale;
   attrFieldSliderGrp -label Wander_tx -min 0 -max 10.0 -at
the_shaker.wander_xtrans_master;
   attrFieldSliderGrp -label Wander_ty -min 0 -max 10.0 -at
the_shaker.wander_ytrans_master;
   attrFieldSliderGrp -label Wander_tz -min 0 -max 10.0 -at
the_shaker.wander_ztrans_master;


     setParent ..;
    setParent ..;


 showWindow shakecontrol;

global proc shakecontrol()
{

if (`window -q -exists shakecontrol` == true)
 deleteUI shakecontrol;


 window -title "The Shaker - R.C.Morris 1998" shakecontrol;

 scrollLayout scrollLayout;
  columnLayout -adjustableColumn true col1;
   frameLayout -label "PRINCIPAL CONTROL" -labelAlign "top"
    -borderStyle "in";
     columnLayout;



   attrFieldSliderGrp -min 0 -max 10.0 -at the_shaker.shake_intensity;
   attrFieldSliderGrp -min 0 -max 10.0 -at the_shaker.jitter_intensity;
   attrFieldSliderGrp -min 0 -max 10.0 -at the_shaker.wander_intensity;
   attrFieldSliderGrp -min 0 -max 10.0 -at
the_shaker.destabilise_intensity;

     setParent ..;
    setParent ..;

   frameLayout -label "FINE CONTROL" -labelAlign "center" -collapsable
true -collapse false
     -borderStyle "etchedOut";
     columnLayout;


   attrFieldSliderGrp -label Shake_tx -min 0 -max 10.0 -at
the_shaker.shake_xtrans_master;
   attrFieldSliderGrp -label Shake_ty -min 0 -max 10.0 -at
the_shaker.shake_ytrans_master;
   attrFieldSliderGrp -label Shake_tz -min 0 -max 10.0 -at
the_shaker.shake_ztrans_master;
   attrFieldSliderGrp -label Shake_rx -min 0 -max 10.0 -at
the_shaker.shake_xrot_master;
   attrFieldSliderGrp -label Shake_ry -min 0 -max 10.0 -at
the_shaker.shake_yrot_master;
   attrFieldSliderGrp -label Shake_rz -min 0 -max 10.0 -at
the_shaker.shake_zrot_master;
   attrFieldSliderGrp -label Jitter_tx -min 0 -max 10.0 -at
the_shaker.jitter_xtrans_master;
   attrFieldSliderGrp -label Jitter_ty -min 0 -max 10.0 -at
the_shaker.jitter_ytrans_master;
   attrFieldSliderGrp -label Jitter_tz -min 0 -max 10.0 -at
the_shaker.jitter_ztrans_master;
   attrFieldSliderGrp -label Jitter_rx -min 0 -max 10.0 -at
the_shaker.jitter_xrot_master;
   attrFieldSliderGrp -label Jitter_ry -min 0 -max 10.0 -at
the_shaker.jitter_yrot_master;
   attrFieldSliderGrp -label Jitter_rz -min 0 -max 10.0 -at
the_shaker.jitter_zrot_master;
   attrFieldSliderGrp -label Destabilise_tx -min 0 -max 10.0 -at
the_shaker.destabilise_xtrans_scale;
   attrFieldSliderGrp -label Destabilise_ty -min 0 -max 10.0 -at
the_shaker.destabilise_ytrans_scale;
   attrFieldSliderGrp -label Destabilise_tz -min 0 -max 10.0 -at
the_shaker.destabilise_ztrans_scale;
   attrFieldSliderGrp -label Destabilise_rx -min 0 -max 10.0 -at
the_shaker.destabilise_xrot_scale;
   attrFieldSliderGrp -label Destabilise_ry -min 0 -max 10.0 -at
the_shaker.destabilise_yrot_scale;
   attrFieldSliderGrp -label Destabilise_rz -min 0 -max 10.0 -at
the_shaker.destabilise_zrot_scale;
   attrFieldSliderGrp -label Wander_tx -min 0 -max 10.0 -at
the_shaker.wander_xtrans_master;
   attrFieldSliderGrp -label Wander_ty -min 0 -max 10.0 -at
the_shaker.wander_ytrans_master;
   attrFieldSliderGrp -label Wander_tz -min 0 -max 10.0 -at
the_shaker.wander_ztrans_master;


     setParent ..;
    setParent ..;
}


// End of the_shaker.ma